==> virtool-workflow-0.5.1.tar.gz: virtool-workflow-0.5.1/virtool_workflow/analysis/hmms.py <==
"""
A class and fixture for accessing Virtool HMM data for use in analysis workflows.

"""
from collections import UserList
from functools import cached_property
from pathlib import Path
from shutil import which
from typing import Iterable, Dict

from virtool_workflow.abc.data_providers.hmms import AbstractHMMsProvider
from virtool_workflow.data_model import HMM
from virtool_workflow.execution.run_subprocess import RunSubprocess
from virtool_workflow.fixtures import fixture


class HMMs(UserList):
    """
    A class that exposes:

    1. A :class:`dict` the links `HMMER <http://hmmer.org/>`_ cluster IDs to Virtool annotation IDs.
    2. The path to the HMM profiles file.

    """
    def __init__(self, hmms: Iterable[HMM], path: Path):
        #: The path to the ``profiles.hmm`` file in the ``work_path`` of the running workflow.
        self.path: Path = path
        super(HMMs, self).__init__(hmms)

    @cached_property
    def cluster_annotation_map(self) -> Dict[int, str]:
        """
        A :class:`dict` that maps cluster IDs used to identify HMMs in `HMMER <http://hmmer.org/>`_ to annotation IDs
        used in Virtool.

        """
        return {hmm.cluster: hmm.id for hmm in self}


@fixture
async def hmms(hmms_provider: AbstractHMMsProvider, work_path: Path, run_subprocess: RunSubprocess):
    """
    A fixture for accessing HMM data.

    The ``*.hmm`` file is copied from the data directory and ``hmmpress`` is run to create all the HMM files.

    Returns an :class:`.HMMs` object containing the path to the HMM profile file and a `dict` that maps HMM cluster numbers to
    database IDs.

    :raises: :class:`RuntimeError`: hmmpress is not installed
    :raises: :class:`RuntimeError`: hmmpress command failed

    """
    await hmms_provider.get_profiles()

    if which("hmmpress") is None:
        raise RuntimeError("hmmpress is not installed.")

    process = await run_subprocess(["hmmpress", str(hmms_provider.path/"profiles.hmm")], wait=True)

    if process.returncode != 0:
        raise RuntimeError("hmmpress command failed")

    return HMMs(await hmms_provider.hmm_list(), hmms_provider.path)

==> virtool-workflow-4.2.2.tar.gz: virtool-workflow-4.2.2/virtool_workflow/analysis/hmms.py <==
"""
A class and fixture for accessing Virtool HMM data for use in analysis workflows.

"""
from collections import UserList
from functools import cached_property
from pathlib import Path
from shutil import which
from typing import Dict, Iterable

from virtool_workflow.api.hmm import HMMsProvider
from virtool_workflow.data_model import HMM
from virtool_workflow.execution.run_subprocess import RunSubprocess

from pyfixtures import fixture


class HMMs(UserList):
    """
    A class that exposes:

    1. A :class:`dict` the links `HMMER <http://hmmer.org/>`_ cluster IDs to Virtool annotation IDs.
    2. The path to the HMM profiles file.

    """

    def __init__(self, hmms: Iterable[HMM], path: Path):
        #: The path to the ``profiles.hmm`` file in the ``work_path`` of the running workflow.
        self.path: Path = path
        super(HMMs, self).__init__(hmms)

    @cached_property
    def cluster_annotation_map(self) -> Dict[int, str]:
        """
        A :class:`dict` that maps cluster IDs used to identify HMMs in `HMMER <http://hmmer.org/>`_ to annotation IDs
        used in Virtool.

        """
        return {hmm.cluster: hmm.id for hmm in self}


@fixture
async def hmms(
    hmms_provider: HMMsProvider, work_path: Path, run_subprocess: RunSubprocess
):
    """
    A fixture for accessing HMM data.

    The ``*.hmm`` file is copied from the data directory and ``hmmpress`` is run to create all the HMM files.

    Returns an :class:`.HMMs` object containing the path to the HMM profile file and a `dict` that maps HMM cluster numbers to
    database IDs.

    :raises: :class:`RuntimeError`: hmmpress is not installed
    :raises: :class:`RuntimeError`: hmmpress command failed

    """
    await hmms_provider.get_profiles()

    if which("hmmpress") is None:
        raise RuntimeError("hmmpress is not installed.")

    process = await run_subprocess(
        ["hmmpress", str(hmms_provider.path / "profiles.hmm")]
    )

    if process.returncode != 0:
        raise RuntimeError("hmmpress command failed")

    return HMMs(await hmms_provider.hmm_list(), hmms_provider.path)
